@@ -10,9 +10,8 @@ from fastapi_user_auth.admin import UserLoginFormAdmin, GroupAdmin, PermissionAd
     UserRegFormAdmin, RoleAdmin, UserInfoFormAdmin  # noqa F401
 from fastapi_user_auth.auth import AuthRouter
 
-
 class UserAuthApp(AdminApp, AuthRouter):
-    page_schema = PageSchema(label=_('User Authentication'), icon='fa fa-lock', sort=99)
+    page_schema = PageSchema(label = _('User Authentication'), icon = 'fa fa-lock', sort = 99)
     router_prefix = '/auth'
     # default admin
     UserLoginFormAdmin: Type[UserLoginFormAdmin] = UserLoginFormAdmin
@@ -28,14 +27,17 @@ class UserAuthApp(AdminApp, AuthRouter):
         AuthRouter.__init__(self)
         self.UserAdmin.model = self.UserAdmin.model or self.auth.user_model
         self.UserLoginFormAdmin.schema = self.UserLoginFormAdmin.schema or schema_create_by_schema(
-            self.auth.user_model, 'UserLoginIn', include={'username', 'password'})
+            self.auth.user_model, 'UserLoginIn', include = {'username', 'password'}
+        )
         self.UserLoginFormAdmin.schema_submit_out = self.UserLoginFormAdmin.schema_submit_out or self.schema_user_login_out
         self.UserRegFormAdmin.schema = self.UserRegFormAdmin.schema or schema_create_by_schema(
-            self.auth.user_model, 'UserRegIn', include={'username', 'password', 'email'})
+            self.auth.user_model, 'UserRegIn', include = {'username', 'password', 'email'}
+        )
         self.UserRegFormAdmin.schema_submit_out = self.UserRegFormAdmin.schema_submit_out or self.schema_user_login_out
         self.UserInfoFormAdmin.schema = self.UserInfoFormAdmin.schema or schema_create_by_schema(
-            self.auth.user_model, 'UserInfoForm', exclude={
-                'id', 'username', 'password', 'is_active', 'parent_id', 'point', 'create_time'})
+            self.auth.user_model, 'UserInfoForm',
+            exclude = {'id', 'username', 'password', 'is_active', 'parent_id', 'point', 'create_time'}
+        )
         self.UserInfoFormAdmin.schema_submit_out = self.UserInfoFormAdmin.schema_submit_out or self.schema_user_info
         # register admin
         self.register_admin(
@@ -50,4 +52,4 @@ class UserAuthApp(AdminApp, AuthRouter):
 
     async def has_page_permission(self, request: Request) -> bool:
         return (await super().has_page_permission(request)
-                and await request.auth.requires(roles='admin', response=False)(request))
+                and await request.auth.requires(roles = 'admin', response = False)(request))
