@@ -5,7 +5,7 @@ import inspect
 from collections.abc import Coroutine
 from typing import Type, Any, TypeVar, Optional, Sequence, Tuple, Union, Callable, Generic
 
-from fastapi import FastAPI, HTTPException, Depends, Form
+from fastapi import FastAPI, HTTPException, Depends, Form, params
 from fastapi.security import OAuth2PasswordBearer
 from fastapi.security.utils import get_authorization_scheme_param
 from fastapi_amis_admin.crud.base import RouterMixin
@@ -15,6 +15,7 @@ from fastapi_amis_admin.utils.functools import cached_property
 from fastapi_amis_admin.utils.translation import i18n as _
 from passlib.context import CryptContext
 from pydantic import BaseModel, SecretStr
+from sqlalchemy.ext.asyncio import AsyncSession
 from sqlalchemy.orm import Session
 from sqlalchemy_database import AsyncDatabase, Database
 from sqlmodel import select
@@ -29,8 +30,7 @@ from .backends.db import DbTokenStore
 from .models import BaseUser, User, Role, UserRoleLink
 from .schemas import UserLoginOut
 
-_UserModelT = TypeVar("_UserModelT", bound=BaseUser)
-
+_UserModelT = TypeVar("_UserModelT", bound = BaseUser)
 
 class AuthBackend(AuthenticationBackend, Generic[_UserModelT]):
 
@@ -47,45 +47,31 @@ class AuthBackend(AuthenticationBackend, Generic[_UserModelT]):
         return token
 
     async def authenticate(self, request: Request) -> Tuple["Auth", Optional[_UserModelT]]:
-        if request.scope.get('auth'):  # 防止重复授权
-            return request.scope.get('auth'), request.scope.get('user')
-        request.scope["auth"], request.scope["user"] = self.auth, None
-        token = self.get_user_token(request)
-        if not token:
-            return self.auth, None
-        token_data = await self.token_store.read_token(token)
-        if token_data is not None:
-            request.scope["user"]: _UserModelT = await self.auth.get_user_by_username(token_data.username)
-        return request.auth, request.user
+        return self.auth, await self.auth.get_current_user(request)
 
     def attach_middleware(self, app: FastAPI):
-        app.add_middleware(AuthenticationMiddleware, backend=self)  # 添加auth中间件
-
+        app.add_middleware(AuthenticationMiddleware, backend = self)  # 添加auth中间件
 
 class Auth(Generic[_UserModelT]):
     user_model: Type[_UserModelT] = None
     db: Union[AsyncDatabase, Database] = None
     backend: AuthBackend[_UserModelT] = None
 
-    def __init__(self, db: Union[AsyncDatabase, Database],
-                 token_store: BaseTokenStore = None,
-                 user_model: Type[_UserModelT] = User,
-                 pwd_context: CryptContext = CryptContext(schemes=["bcrypt"], deprecated="auto")
-                 ):
+    def __init__(
+        self,
+        db: Union[AsyncDatabase, Database],
+        token_store: BaseTokenStore = None,
+        user_model: Type[_UserModelT] = User,
+        pwd_context: CryptContext = CryptContext(schemes = ["bcrypt"], deprecated = "auto")
+    ):
         self.user_model = user_model or self.user_model
         assert self.user_model, 'user_model is None'
         self.db = db or self.db
         self.backend = self.backend or AuthBackend(self, token_store or DbTokenStore(self.db))
         self.pwd_context = pwd_context
 
-    async def get_user_by_username(self, username: str) -> Optional[_UserModelT]:
-        return await self.get_user_by_whereclause(self.user_model.username == username)
-
-    async def get_user_by_whereclause(self, *whereclause: Any) -> Optional[_UserModelT]:
-        return await self.db.async_scalar(select(self.user_model).where(*whereclause))
-
     async def authenticate_user(self, username: str, password: Union[str, SecretStr]) -> Optional[_UserModelT]:
-        user = await self.get_user_by_username(username)
+        user = await self.db.async_scalar(select(self.user_model).where(self.user_model.username == username))
         if user:
             pwd = password.get_secret_value() if isinstance(password, SecretStr) else password
             pwd2 = user.password.get_secret_value() if isinstance(user.password, SecretStr) else user.password
@@ -93,37 +79,58 @@ class Auth(Generic[_UserModelT]):
                 return user
         return None
 
-    def requires(self,
-                 roles: Union[str, Sequence[str]] = None,
-                 groups: Union[str, Sequence[str]] = None,
-                 permissions: Union[str, Sequence[str]] = None,
-                 status_code: int = 403,
-                 redirect: str = None,
-                 response: Optional[Union[Response, bool]] = None,
-                 ) -> Callable:  # sourcery no-metrics
+    @cached_property
+    def get_current_user(self):
+        async def _get_current_user(
+            request: Request,
+            session: Union[Session, AsyncSession, None] = Depends(self.db.session_generator)
+        ) -> Optional[_UserModelT]:
+            if request.scope.get('auth'):  # 防止重复授权
+                return request.scope.get('user')
+            request.scope["auth"], request.scope["user"] = self, None
+            token = self.backend.get_user_token(request)
+            if not token:
+                return None
+            token_data = await self.backend.token_store.read_token(token)
+            if token_data is not None:
+                request.scope["user"]: _UserModelT = await self.db.async_get(self.user_model, token_data.id, session = session)
+            return request.user
 
-        async def has_requires(conn: HTTPConnection):
-            # todo websocket support
-            await self.backend.authenticate(conn)  # type:ignore
-            if not conn.user:
-                return False
-            return await self.db.async_run_sync(
-                conn.user.has_requires,
-                roles=roles,
-                groups=groups,
-                permissions=permissions,
-                is_session=True
+        return _get_current_user
+
+    def requires(
+        self,
+        roles: Union[str, Sequence[str]] = None,
+        groups: Union[str, Sequence[str]] = None,
+        permissions: Union[str, Sequence[str]] = None,
+        status_code: int = 403,
+        redirect: str = None,
+        response: Union[bool, Response] = None,
+    ) -> Callable:  # sourcery no-metrics
+
+        async def has_requires(user: _UserModelT) -> bool:
+            return user and await self.db.async_run_sync(
+                user.has_requires,
+                roles = roles,
+                groups = groups,
+                permissions = permissions,
+                is_session = True
             )
 
-        async def depend(request: Request):
-            if not await has_requires(request):
-                if redirect is not None:
-                    return RedirectResponse(
-                        url=request.url_for(redirect), status_code=303
-                    )
+        async def depend(
+            request: Request,
+            user: _UserModelT = Depends(self.get_current_user),
+        ) -> Union[bool, Response]:
+            if isinstance(user, params.Depends):
+                user = await self.get_current_user(request)
+            if not await has_requires(user):
                 if response is not None:
                     return response
-                raise HTTPException(status_code=status_code)
+                code, headers = status_code, {}
+                if redirect is not None:
+                    code = 307
+                    headers = {'location': request.url_for(redirect)}
+                raise HTTPException(status_code = code, headers = headers)
             return True
 
         def decorator(func: Callable = None) -> Union[Callable, Coroutine]:
@@ -145,11 +152,12 @@ class Auth(Generic[_UserModelT]):
                 # Handle websocket functions. (Always async)
                 @functools.wraps(func)
                 async def websocket_wrapper(
-                        *args: Any, **kwargs: Any
+                    *args: Any, **kwargs: Any
                 ) -> None:
                     websocket = kwargs.get("websocket", args[idx] if args else None)
                     assert isinstance(websocket, WebSocket)
-                    if not await has_requires(websocket):
+                    user = await self.get_current_user(websocket)  # type: ignore
+                    if not await has_requires(user):
                         await websocket.close()
                     else:
                         await func(*args, **kwargs)
@@ -160,7 +168,7 @@ class Auth(Generic[_UserModelT]):
                 # Handle async request/response functions.
                 @functools.wraps(func)
                 async def async_wrapper(
-                        *args: Any, **kwargs: Any
+                    *args: Any, **kwargs: Any
                 ) -> Response:
                     request = kwargs.get("request", args[idx] if args else None)
                     assert isinstance(request, Request)
@@ -192,7 +200,7 @@ class Auth(Generic[_UserModelT]):
         # create admin role
         role = session.scalar(select(Role).where(Role.key == role_key))
         if not role:
-            role = Role(key=role_key, name=f'{role_key} role')
+            role = Role(key = role_key, name = f'{role_key} role')
             session.add(role)
             session.flush()
 
@@ -200,13 +208,14 @@ class Auth(Generic[_UserModelT]):
         user = session.scalar(
             select(self.user_model).join(
                 UserRoleLink, UserRoleLink.user_id == self.user_model.id
-            ).where(UserRoleLink.role_id == role.id))
+            ).where(UserRoleLink.role_id == role.id)
+        )
         if not user:
             user = self.user_model(
-                username=role_key,
-                password=self.pwd_context.hash(role_key),
-                email=f'{role_key}@amis.work',  # type:ignore
-                roles=[role],
+                username = role_key,
+                password = self.pwd_context.hash(role_key),
+                email = f'{role_key}@amis.work',  # type:ignore
+                roles = [role],
             )
             session.add(user)
             session.flush()
@@ -217,10 +226,9 @@ class Auth(Generic[_UserModelT]):
         return await self.db.async_run_sync(
             self._create_role_user_sync,
             role_key,
-            on_close_pre=lambda user: User.parse_obj(user)
+            on_close_pre = lambda user: User.parse_obj(user)
         )
 
-
 class AuthRouter(RouterMixin):
     auth: Auth = None
     schema_user_login_out: Type[UserLoginOut] = UserLoginOut
@@ -233,17 +241,25 @@ class AuthRouter(RouterMixin):
         RouterMixin.__init__(self)
         self.router.dependencies.insert(0, Depends(self.auth.backend.authenticate))
         self.schema_user_info = self.schema_user_info or schema_create_by_schema(
-            self.auth.user_model, 'UserInfo', exclude={'password'})
+            self.auth.user_model, 'UserInfo', exclude = {'password'}
+        )
 
-        self.router.add_api_route('/userinfo', self.route_userinfo, methods=["GET"], description=_('User Profile'),
-                                  dependencies=None, response_model=BaseApiOut[self.schema_user_info])
-        self.router.add_api_route('/logout', self.route_logout, methods=["GET"], description=_('Sign out'),
-                                  dependencies=None, response_model=BaseApiOut)
+        self.router.add_api_route(
+            '/userinfo', self.route_userinfo, methods = ["GET"], description = _('User Profile'),
+            dependencies = None, response_model = BaseApiOut[self.schema_user_info]
+        )
+        self.router.add_api_route(
+            '/logout', self.route_logout, methods = ["GET"], description = _('Sign out'),
+            dependencies = None, response_model = BaseApiOut
+        )
         # oauth2
         self.router.dependencies.append(
-            Depends(self.OAuth2(tokenUrl=f"{self.router_path}/gettoken", auto_error=False)))
-        self.router.add_api_route('/gettoken', self.route_gettoken, methods=["POST"], description='OAuth2 Token',
-                                  response_model=BaseApiOut[self.schema_user_login_out])
+            Depends(self.OAuth2(tokenUrl = f"{self.router_path}/gettoken", auto_error = False))
+        )
+        self.router.add_api_route(
+            '/gettoken', self.route_gettoken, methods = ["POST"], description = 'OAuth2 Token',
+            response_model = BaseApiOut[self.schema_user_login_out]
+        )
 
     @cached_property
     def router_path(self) -> str:
@@ -253,7 +269,7 @@ class AuthRouter(RouterMixin):
     def route_userinfo(self):
         @self.auth.requires()
         async def userinfo(request: Request):
-            return BaseApiOut(data=request.user)
+            return BaseApiOut(data = request.user)
 
         return userinfo
 
@@ -261,10 +277,10 @@ class AuthRouter(RouterMixin):
     def route_logout(self):
         @self.auth.requires()
         async def user_logout(request: Request):
-            token_value = request.auth.backend.get_user_token(request=request)
+            token_value = request.auth.backend.get_user_token(request = request)
             with contextlib.suppress(Exception):
-                await self.auth.backend.token_store.destroy_token(token=token_value)
-            response = RedirectResponse(url='/')
+                await self.auth.backend.token_store.destroy_token(token = token_value)
+            response = RedirectResponse(url = '/')
             response.delete_cookie('Authorization')
             return response
 
@@ -272,22 +288,24 @@ class AuthRouter(RouterMixin):
 
     @property
     def route_gettoken(self):
-        async def oauth_token(request: Request,
-                              response: Response,
-                              username: str = Form(...),
-                              password: str = Form(...)
-                              ):
+        async def oauth_token(
+            request: Request,
+            response: Response,
+            username: str = Form(...),
+            password: str = Form(...)
+        ):
             if request.scope.get('user') is None:
-                request.scope['user'] = await request.auth.authenticate_user(username=username, password=password)
+                request.scope['user'] = await request.auth.authenticate_user(username = username, password = password)
             if request.scope.get('user') is None:
-                return BaseApiOut(status=-1, msg=_('Incorrect username or password!'))
+                return BaseApiOut(status = -1, msg = _('Incorrect username or password!'))
             token_info = self.schema_user_login_out.parse_obj(request.user)
             token_info.access_token = await request.auth.backend.token_store.write_token(request.user.dict())
             response.set_cookie('Authorization', f'bearer {token_info.access_token}')
-            return BaseApiOut(data=token_info)
+            return BaseApiOut(data = token_info)
 
         return oauth_token
 
     class OAuth2(OAuth2PasswordBearer):
+
         async def __call__(self, request: Request) -> Optional[str]:
             return request.auth.backend.get_user_token(request)
