@@ -13,88 +13,85 @@ from sqlmodel.sql.expression import SelectOfScalar
 
 SelectOfScalar.inherit_cache = True
 
+class PkMixin(SQLModel):
+    id: int = Field(default = None, primary_key = True, nullable = False)
 
-class SQLModelTable(SQLModel):
-    id: int = Field(default=None, primary_key=True, nullable=False)
+class CreateTimeMixin(SQLModel):
+    create_time: datetime = Field(default_factory = datetime.now, title = _('Create Time'))
 
-
-class UserRoleLink(SQLModel, table=True):
-    __tablename__ = 'auth_user_roles'
-    user_id: Optional[int] = Field(
-        default=None, foreign_key="auth_user.id", primary_key=True, nullable=False
-    )
-    role_id: Optional[int] = Field(
-        default=None, foreign_key="auth_role.id", primary_key=True, nullable=False
-    )
-
-
-class UserGroupLink(SQLModel, table=True):
-    __tablename__ = 'auth_user_groups'
-    user_id: Optional[int] = Field(
-        default=None, foreign_key="auth_user.id", primary_key=True, nullable=False
-    )
-    group_id: Optional[int] = Field(
-        default=None, foreign_key="auth_group.id", primary_key=True, nullable=False
-    )
-
-
-class GroupRoleLink(SQLModel, table=True):
-    __tablename__ = 'auth_group_roles'
-    group_id: Optional[int] = Field(
-        default=None, foreign_key="auth_group.id", primary_key=True, nullable=False
-    )
-    role_id: Optional[int] = Field(
-        default=None, foreign_key="auth_role.id", primary_key=True, nullable=False
-    )
-
-
-class RolePermissionLink(SQLModel, table=True):
-    __tablename__ = 'auth_role_permissions'
-    role_id: Optional[int] = Field(
-        default=None, foreign_key="auth_role.id", primary_key=True, nullable=False
-    )
-    permission_id: Optional[int] = Field(
-        default=None, foreign_key="auth_permission.id", primary_key=True, nullable=False
-    )
-
-
-class UserUsername(SQLModel):
+class UsernameMixin(SQLModel):
     username: str = Field(
-        title=_('Username'), max_length=32,
-        sa_column=Column(String(32), unique=True, index=True, nullable=False)
+        title = _('Username'), max_length = 32,
+        sa_column = Column(String(32), unique = True, index = True, nullable = False)
     )
 
-
 class PasswordStr(SecretStr, str):
     pass
 
-
-class UserPassword(SQLModel):
+class PasswordMixin(SQLModel):
     password: PasswordStr = Field(
-        title=_('Password'), max_length=128,
-        sa_column=Column(String(128), nullable=False),
-        amis_form_item='input-password'
+        title = _('Password'), max_length = 128,
+        sa_column = Column(String(128), nullable = False),
+        amis_form_item = 'input-password'
     )
 
-
-class UserEmail(SQLModel):
+class EmailMixin(SQLModel):
     email: EmailStr = Field(
-        title=_('Email'),
-        sa_column=Column(String(50), unique=True, index=True, nullable=False),
-        amis_form_item='input-email'
+        None,
+        title = _('Email'),
+        sa_column = Column(String(50), unique = True, index = True, nullable = False),
+        amis_form_item = 'input-email'
     )
 
+class UserRoleLink(SQLModel, table = True):
+    __tablename__ = 'auth_user_roles'
+    user_id: Optional[int] = Field(
+        default = None, foreign_key = "auth_user.id", primary_key = True, nullable = False
+    )
+    role_id: Optional[int] = Field(
+        default = None, foreign_key = "auth_role.id", primary_key = True, nullable = False
+    )
 
-class BaseUser(UserEmail, UserPassword, UserUsername, SQLModelTable):
+class UserGroupLink(SQLModel, table = True):
+    __tablename__ = 'auth_user_groups'
+    user_id: Optional[int] = Field(
+        default = None, foreign_key = "auth_user.id", primary_key = True, nullable = False
+    )
+    group_id: Optional[int] = Field(
+        default = None, foreign_key = "auth_group.id", primary_key = True, nullable = False
+    )
+
+class GroupRoleLink(SQLModel, table = True):
+    __tablename__ = 'auth_group_roles'
+    group_id: Optional[int] = Field(
+        default = None, foreign_key = "auth_group.id", primary_key = True, nullable = False
+    )
+    role_id: Optional[int] = Field(
+        default = None, foreign_key = "auth_role.id", primary_key = True, nullable = False
+    )
+
+class RolePermissionLink(SQLModel, table = True):
+    __tablename__ = 'auth_role_permissions'
+    role_id: Optional[int] = Field(
+        default = None, foreign_key = "auth_role.id", primary_key = True, nullable = False
+    )
+    permission_id: Optional[int] = Field(
+        default = None, foreign_key = "auth_permission.id", primary_key = True, nullable = False
+    )
+
+class BaseUser(PkMixin, UsernameMixin, PasswordMixin, EmailMixin, CreateTimeMixin):
     __tablename__ = 'auth_user'
     __table_args__ = {'extend_existing': True}
-    is_active: bool = Field(default=True, title=_('Is Active'))
-    nickname: str = Field(None, title=_('Nickname'), max_length=32)
-    avatar: str = Field(None, title=_('Avatar'), max_length=100,
-                        amis_form_item=InputImage(maxLength=1, maxSize=2 * 1024 * 1024,
-                                                  receiver='post:/admin/file/upload'),
-                        amis_table_column=ColumnImage(width=50, height=50, enlargeAble=True))
-    create_time: datetime = Field(default_factory=datetime.utcnow, title=_('Create Time'))
+    is_active: bool = Field(default = True, title = _('Is Active'))
+    nickname: str = Field(None, title = _('Nickname'), max_length = 32)
+    avatar: str = Field(
+        None, title = _('Avatar'), max_length = 100,
+        amis_form_item = InputImage(
+            maxLength = 1, maxSize = 2 * 1024 * 1024,
+            receiver = 'post:/admin/file/upload'
+        ),
+        amis_table_column = ColumnImage(width = 50, height = 50, enlargeAble = True)
+    )
 
     class Config:
         use_enum_values = True
@@ -118,7 +115,8 @@ class BaseUser(UserEmail, UserPassword, UserUsername, SQLModelTable):
         ).where(*role_whereclause)
         # check user group
         role_group_ids = select(GroupRoleLink.group_id).join(
-            Role, and_(*role_whereclause, Role.id == GroupRoleLink.role_id))
+            Role, and_(*role_whereclause, Role.id == GroupRoleLink.role_id)
+        )
         group_user_ids = select(UserGroupLink.user_id).where(UserGroupLink.user_id == self.id).where(
             UserGroupLink.group_id.in_(role_group_ids)
         )
@@ -164,12 +162,12 @@ class BaseUser(UserEmail, UserPassword, UserUsername, SQLModelTable):
         return self._exists_role(Role.id.in_(role_ids))
 
     def has_requires(
-            self,
-            session: Session,
-            *,
-            roles: Union[str, Sequence[str]] = None,
-            groups: Union[str, Sequence[str]] = None,
-            permissions: Union[str, Sequence[str]] = None,
+        self,
+        session: Session,
+        *,
+        roles: Union[str, Sequence[str]] = None,
+        groups: Union[str, Sequence[str]] = None,
+        permissions: Union[str, Sequence[str]] = None,
     ) -> bool:
         """
         检查用户是否属于拥有指定的RBAC权限
@@ -194,46 +192,41 @@ class BaseUser(UserEmail, UserPassword, UserUsername, SQLModelTable):
             stmt = stmt.where(self._exists_permissions(permissions_list))
         return bool(session.scalar(stmt))
 
-
-class User(BaseUser, table=True):
+class User(BaseUser, table = True):
     """用户"""
-    point: float = Field(default=0, title=_('Point'))
-    phone: str = Field(None, title=_('Tel'), max_length=15)
-    parent_id: int = Field(None, title=_('Parent'), foreign_key="auth_user.id")
+    point: float = Field(default = 0, title = _('Point'))
+    phone: str = Field(None, title = _('Tel'), max_length = 15)
+    parent_id: int = Field(None, title = _('Parent'), foreign_key = "auth_user.id")
     children: List["User"] = Relationship(
-        sa_relationship_kwargs=dict(
-            backref=backref("parent", remote_side="User.id"),
+        sa_relationship_kwargs = dict(
+            backref = backref("parent", remote_side = "User.id"),
         ),
     )
-    roles: List["Role"] = Relationship(back_populates="users", link_model=UserRoleLink)
-    groups: List["Group"] = Relationship(back_populates="users", link_model=UserGroupLink)
+    roles: List["Role"] = Relationship(link_model = UserRoleLink)
+    groups: List["Group"] = Relationship(link_model = UserGroupLink)
 
-
-class BaseRBAC(SQLModelTable):
+class BaseRBAC(PkMixin):
     __table_args__ = {'extend_existing': True}
-    key: str = Field(..., title=_('Identify'), max_length=20,
-                     sa_column=Column(String(20), unique=True, index=True, nullable=False))
-    name: str = Field(..., title=_('Name'), max_length=20)
-    desc: str = Field(default='', title=_('Description'), max_length=400, amis_form_item='textarea')
+    key: str = Field(
+        ..., title = _('Identify'), max_length = 20,
+        sa_column = Column(String(20), unique = True, index = True, nullable = False)
+    )
+    name: str = Field(..., title = _('Name'), max_length = 20)
+    desc: str = Field(default = '', title = _('Description'), max_length = 400, amis_form_item = 'textarea')
 
-
-class Role(BaseRBAC, table=True):
+class Role(BaseRBAC, table = True):
     """角色"""
     __tablename__ = 'auth_role'
-    users: List[User] = Relationship(back_populates="roles", link_model=UserRoleLink)
-    groups: List["Group"] = Relationship(back_populates="roles", link_model=GroupRoleLink)
-    permissions: List["Permission"] = Relationship(back_populates="roles", link_model=RolePermissionLink)
+    groups: List["Group"] = Relationship(back_populates = "roles", link_model = GroupRoleLink)
+    permissions: List["Permission"] = Relationship(back_populates = "roles", link_model = RolePermissionLink)
 
-
-class Group(BaseRBAC, table=True):
+class Group(BaseRBAC, table = True):
     """用户组"""
     __tablename__ = 'auth_group'
-    parent_id: int = Field(None, title=_('Parent'), foreign_key="auth_group.id")
-    users: List[User] = Relationship(back_populates="groups", link_model=UserGroupLink)
-    roles: List["Role"] = Relationship(back_populates="groups", link_model=GroupRoleLink)
+    parent_id: int = Field(None, title = _('Parent'), foreign_key = "auth_group.id")
+    roles: List["Role"] = Relationship(back_populates = "groups", link_model = GroupRoleLink)
 
-
-class Permission(BaseRBAC, table=True):
+class Permission(BaseRBAC, table = True):
     """权限"""
     __tablename__ = 'auth_permission'
-    roles: List["Role"] = Relationship(back_populates="permissions", link_model=RolePermissionLink)
+    roles: List["Role"] = Relationship(back_populates = "permissions", link_model = RolePermissionLink)
